.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay 

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

batch
=====

.. _xsimd-batch-ref:

.. doxygenclass:: xsimd::batch
   :project: xsimd
   :members:

